{
  "module_spec": {
    "module_name": "Auth",
    "module_description": "Authoritative service",
    "config_data": [
      { "item_name": "database_file",
        "item_type": "string",
        "item_optional": true,
        "item_default": "/var/bind10/zone.sqlite3"
      },
      { "item_name": "datasources",
        "item_type": "list",
        "item_optional": true,
        "item_default": [],
        "list_item_spec":
        { "item_name": "list_element",
          "item_type": "map",
          "item_optional": false,
          "item_default": {},
          "map_item_spec": [
          { "item_name": "type",
            "item_type": "string",
            "item_optional": false,
            "item_default": ""
          },
          { "item_name": "class",
            "item_type": "string",
            "item_optional": false,
            "item_default": "IN"
          },
          { "item_name": "zones",
            "item_type": "list",
            "item_optional": false,
            "item_default": [],
            "list_item_spec":
            { "item_name": "list_element",
              "item_type": "map",
              "item_optional": true,
              "item_default": { "origin": "", "file": "" },
              "map_item_spec": [
              { "item_name": "origin",
                "item_type": "string",
                "item_optional": false,
                "item_default": ""
              },
              { "item_name": "file",
                "item_type": "string",
                "item_optional": false,
                "item_default": ""
              },
              { "item_name": "filetype",
                "item_type": "string",
                "item_optional": true
              }]
            }
          }]
        }
      },
      {
        "item_name": "listen_on",
        "item_type": "list",
        "item_optional": false,
        "item_default": [
          {
            "address": "::",
            "port": 53
          },
          {
            "address": "0.0.0.0",
            "port": 53
          }
        ],
        "list_item_spec": {
          "item_name": "address",
          "item_type": "map",
          "item_optional": false,
          "item_default": {},
          "map_item_spec": [
            {
              "item_name": "address",
              "item_type": "string",
              "item_optional": false,
              "item_default": "::1"
            },
            {
              "item_name": "port",
              "item_type": "integer",
              "item_optional": false,
              "item_default": 53
            }
          ]
        }
      },
      { "item_name": "tcp_recv_timeout",
        "item_type": "integer",
        "item_optional": false,
        "item_default": 5000
      }
    ],
    "commands": [
      {
        "command_name": "shutdown",
        "command_description": "Shut down authoritative DNS server",
        "command_args": [
          {
            "item_name": "pid",
            "item_type": "integer",
            "item_optional": true
          }
        ]
      },
      {
        "command_name": "getstats",
        "command_description": "Retrieve statistics data",
        "command_args": []
      },
      {
        "command_name": "loadzone",
        "command_description": "(Re)load a specified zone",
        "command_args": [
          {
            "item_name": "class", "item_type": "string",
            "item_optional": true, "item_default": "IN"
          },
	  {
            "item_name": "origin", "item_type": "string",
            "item_optional": false, "item_default": ""
          }
        ]
      },
      {
        "command_name": "start_ddns_forwarder",
        "command_description": "(Re)start internal forwarding of DDNS Update messages. This is automatically called if b10-ddns is started, and is not expected to be called by administrators; it will be removed as a public command in the future.",
        "command_args": []
      },
      {
        "command_name": "stop_ddns_forwarder",
        "command_description": "Stop internal forwarding of DDNS Update messages. This is automatically called if b10-ddns is stopped, and is not expected to be called by administrators; it will be removed as a public command in the future.",
        "command_args": []
      }
    ],
    "statistics": [
      {
        "item_name": "queries.tcp",
        "item_type": "integer",
        "item_optional": false,
        "item_default": 0,
        "item_title": "Queries TCP",
        "item_description": "A number of total query counts which all auth servers receive over TCP since they started initially"
      },
      {
        "item_name": "queries.udp",
        "item_type": "integer",
        "item_optional": false,
        "item_default": 0,
        "item_title": "Queries UDP",
        "item_description": "A number of total query counts which all auth servers receive over UDP since they started initially"
      },
      {
        "item_name": "opcode.query",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Received query requests",
        "item_description": "The number of total request counts whose opcode is query"
      },
      {
        "item_name": "opcode.iquery",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Received inverse query requests",
        "item_description": "The number of total request counts whose opcode is inverse query"
      },
      {
        "item_name": "opcode.status",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Received status requests",
        "item_description": "The number of total request counts whose opcode is status"
      },
      {
        "item_name": "opcode.notify",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Received notify requests",
        "item_description": "The number of total request counts whose opcode is notify"
      },
      {
        "item_name": "opcode.update",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Received update requests",
        "item_description": "The number of total request counts whose opcode is update"
      },
      {
        "item_name": "opcode.other",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Received requests opcode other",
        "item_description": "The number of total request counts whose opcode is other (not well-known)"
      },
      {
        "item_name": "rcode.noerror",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent success response",
        "item_description": "The number of total responses with rcode 0 (NOERROR)"
      },
      {
        "item_name": "rcode.formerr",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'format error' response",
        "item_description": "The number of total responses with rcode 1 (FORMERR)"
      },
      {
        "item_name": "rcode.servfail",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'server failure' response",
        "item_description": "The number of total responses with rcode 2 (SERVFAIL)"
      },
      {
        "item_name": "rcode.nxdomain",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'name error' response",
        "item_description": "The number of total responses with rcode 3 (NXDOMAIN)"
      },
      {
        "item_name": "rcode.notimp",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'not implemented' response",
        "item_description": "The number of total responses with rcode 4 (NOTIMP)"
      },
      {
        "item_name": "rcode.refused",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'refused' response",
        "item_description": "The number of total responses with rcode 5 (REFUSED)"
      },
      {
        "item_name": "rcode.yxdomain",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'name unexpectedly exists' response",
        "item_description": "The number of total responses with rcode 6 (YXDOMAIN)"
      },
      {
        "item_name": "rcode.yxrrset",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'rrset unexpectedly exists' response",
        "item_description": "The number of total responses with rcode 7 (YXRRSET)"
      },
      {
        "item_name": "rcode.nxrrset",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'no such rrset' response",
        "item_description": "The number of total responses with rcode 8 (NXRRSET)"
      },
      {
        "item_name": "rcode.notauth",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'not authoritative' response",
        "item_description": "The number of total responses with rcode 9 (NOTAUTH)"
      },
      {
        "item_name": "rcode.notzone",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'name not in zone' response",
        "item_description": "The number of total responses with rcode 10 (NOTZONE)"
      },
      {
        "item_name": "rcode.badsigvers",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'EDNS version not implemented' response",
        "item_description": "The number of total responses with rcode 16 (BADVERS)"
      },
      {
        "item_name": "rcode.badkey",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'Key not recognized' response",
        "item_description": "The number of total responses with rcode 17 (BADKEY)"
      },
      {
        "item_name": "rcode.badtime",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'Signature out of time window' response",
        "item_description": "The number of total responses with rcode 18 (BADTIME)"
      },
      {
        "item_name": "rcode.badmode",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'Bad TKEY Mode' response",
        "item_description": "The number of total responses with rcode 19 (BADMODE)"
      },
      {
        "item_name": "rcode.badname",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'Duplicate key name' response",
        "item_description": "The number of total responses with rcode 20 (BADNAME)"
      },
      {
        "item_name": "rcode.badalg",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'Algorithm not supported' response",
        "item_description": "The number of total responses with rcode 21 (BADALG)"
      },
      {
        "item_name": "rcode.badtrunc",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent 'Bad Truncation' response",
        "item_description": "The number of total responses with rcode 22 (BADTRUNC)"
      },
      {
        "item_name": "rcode.other",
        "item_type": "integer",
        "item_optional": true,
        "item_default": 0,
        "item_title": "Sent responses with rcode other",
        "item_description": "The number of total responses with rcode other (not well-known)"
      }
    ]
  }
}
